@@ -2,6 +2,7 @@ from MSApi.exceptions import *
 from MSApi.properties import *
 import requests
 
+from datetime import datetime
 
 ms_url = "https://online.moysklad.ru/api/remap/1.2"
 
@@ -14,6 +15,11 @@ def error_handler(response: requests.Response, expected_code=200):
     raise MSApiHttpException(response)
 
 
+def string_to_datetime(string):
+    value = datetime.strptime('%Y-%m-%d %H:%M:%S.%f', string + "000")
+    return value
+
+
 class Authorizer:
     token = None
 
